# zoo-frontend

本次建设的动物信息分为以下功能：

1. 数据录入与管理
   系统应提供数据录入功能，允许用户输入动物的基本信息，如种类、年龄、性别、体重、健康状况等。同时，系统应具备数据管理功能，包括数据的查询、修改、删除等操作，以便用户能够方便地管理和维护动物信息。

2. 动物档案管理
   系统应建立动物档案，记录动物的整个生命周期，包括出生日期、疫苗接种记录、疾病治疗记录、饲养记录等。这有助于跟踪动物的健康状况和饲养情况，为动物提供更好的管理和照顾。

3. 饲养管理
   系统应提供饲养管理功能，包括饲养计划的制定、饲养任务的分配、饲养记录的管理等。这有助于确保动物获得适当的饲料和营养，保持健康生长。

4. 健康监测与预警
   系统应具备健康监测功能，定期收集和分析动物的健康数据，如体温、心率、呼吸频率等。同时，系统应提供预警功能，当动物的健康数据出现异常时，及时提醒管理人员采取相应措施。

5. 统计分析
   系统应提供统计分析功能，对动物信息、饲养记录、健康数据等进行统计分析，生成各类报表和图表。这有助于管理人员了解动物的整体状况和饲养效果，为决策提供支持。

6. 用户权限管理
   系统应建立用户权限管理机制，对不同用户设置不同的权限，如管理员、饲养员、兽医等。这有助于确保系统的安全性和数据的保密性。

使用的技术/资源：

- vue3
- ElementUI
- axios

# 需要后端提供的数据

一切以最终实现的接口为准，你需要前端提供什么数据就什么数据

## 登录功能

前端提供参数

```json
{
  "user": {
    "username": "user1",
    "password": "123456"
  }
}
```

需要后端返回标识用户身份的数据，012代表三种用户身份

最少需要的数据有：
用户名、身份标识

## 用户管理功能
---

### 用户查询

前端提供：一个用户id或者不提供，提供id就返回单个用户，不提供就返回所有用户

若成功，返回所有用户的结果集（节省时间不搞分页了）

### 用户添加

前端提供的数据一个用户对象

后端添加该对象进数据库

后端返回状态码，哪个码表示什么意思记得写一下

### 用户删除

前端提供：要删除的用户id

后端删除对应的用户返回结果

### 用户编辑
前端提供：一个用户对象

后端修改对应的用户返回结果

## 动物信息管理功能
---

### 动物查询

前端提供的数据，动物id或者不提供

后端返回单个动物或所有动物

### 动物添加

前端提供数据：一个动物对象

后端添加该对象返回操作结果

### 动物删除

前端提供：动物id

后端删除对应的动物，返回结果

### 动物编辑

前端提供：一个动物对象

后端修改对应的动物返回结果

## 饲养管理
---

需要后端创建一个表，为了节省时间不需要设置外键什么的
```
breedingPlan: {
        id: '',//int 饲养计划id
        name: '',//字符 饲养计划名称
        species: '',//字符 种类
        sex: '雄性',//字符 饲养动物性别
        phase: '',//字符 饲养动物生长阶段：幼年期、成长期、成年期、老年期
        state: 0,//int 状态（0正常 1异常）
        roleId: null,//负责执行计划的饲养员id
        describe: ''//字符 饲养计划的描述
      }
```

### 饲养计划查询

前端提供：饲养计划id或者不提供

后端返回单个饲养计划或所有饲养计划

### 饲养计划添加

前端提供：一个饲养计划对象

后端添加该对象并返回操作结果

### 饲养计划删除

前端提供：饲养计划id

后端删除该饲养计划并返回操作结果

### 饲养计划修改

前端提供：一个饲养计划对象

后端添加该对象并返回操作结果

## 档案管理



## 健康检测

## 统计分析


# 开发进度

## 登录界面

- [x] 基本组件布局
- [x] 基本方法
- [ ] 对接后端
- [ ] 优化界面样式

## 主页

### header

- [x] 基本界面
- [x] 基本方法
- [ ] 优化界面样式

### aside

- [x] 基本界面
- [x] 基本方法
- [ ] 优化界面样式

### footer

- [x] 基本界面
- [ ] 优化界面样式

### main

- [x] 基本界面
- [ ] 基本方法
- [ ] 优化界面样式

## 内容页面

### 管理员

- [x] 数据展示
- [x] 基本功能
- [x] 基本方法
- [ ] 接入后端

### 饲养员

- [x] 数据展示
- [ ] 基本功能
- [ ] 基本方法
- [ ] 接入后端

### 兽医

- [ ] 数据展示
- [ ] 基本功能
- [ ] 基本方法
- [ ] 接入后端

## 需求分析

一、引言

动物园信息管理系统旨在为动物园内部人员（如系统管理员、饲养员、兽医等）提供一个便捷、高效的管理工具，以记录动物数据、提高管理效率、保障动物健康和福利。通过该系统，可以实时监控动物的各项体征数据，判断动物是否健康，并根据数据优化动物的生活环境，确保动物处于相对健康的状态。

二、系统用户

1. 系统管理员

- 用户与权限管理：负责创建、修改和删除用户账户，分配不同角色的权限，确保系统数据的安全性和完整性。（用户管理，重要）
- 系统设置与维护：进行系统参数配置，如数据备份策略、系统日志管理等，确保系统的稳定运行。（不重要）
- 数据监控与报告：实时监控动物数据异常情况，生成各类统计报告，为动物园管理层提供决策支持。（统计分析，一般）

3. 饲养员

- 动物日常饲养记录：录入动物的饮食、行为、活动等日常饲养信息，确保数据的准确性和完整性。（饲养管理，重要）
- 饲养计划制定与执行：根据动物种类、年龄、健康状况等因素，制定合理的饲养计划，并监控计划的执行情况。（饲养管理，一般）
- 食物库存管理：预估食物库存情况，及时补充库存，避免食物短缺或浪费。（不重要）
- 报警系统响应：接收系统发出的异常报警，及时处理异常情况，保障动物健康与安全。（不重要）

5. 兽医

- 动物体检数据录入与分析：录入动物的体重、体温、心跳等体征数据，进行健康评估，并生成诊断报告。（动物档案、健康检测，重要）
- 疾病治疗与记录：制定治疗方案，记录治疗过程及效果，为动物健康提供有力保障。（动物档案，重要）
- 报警系统响应：根据系统发出的异常报警，及时对患病动物进行诊断和治疗。（不重要）

三、功能需求

1. 数据管理（重要）

- 信息录入：动物基本信息的录入和管理，包括种类、年龄、性别、体重、健康状况等。（重要）
- 动物日常记录：饲养员可以记录动物的饮食、行为、活动等情况。
- 动物体检数据录入：兽医可以实时更新动物的体重、体温、心跳、呼吸等体征数据，并上传相关诊断报告。
- 动物档案管理：系统应该能够完整记录动物的生命周期信息，如出生日期、疫苗接种记录、疾病治疗记录、饲养记录等，确保数据的完整性和准确性。

3. 数据查询与统计（重要）

- 提供多种查询方式，如按动物种类、年龄、性别等条件查询动物信息。
- 统计动物数量、饲养成本、疾病发生率等数据，为动物园管理提供决策支持。

5. 健康与福利管理（一般）

- 实时监控动物体征数据，设置异常数据阈值，当数据超过阈值时自动报警。
- 提供动物健康评估功能，根据体征数据判断动物健康状态，并给出相应建议。
- 记录动物福利措施实施情况，如改善动物生活环境、增加娱乐设施等。

7. 权限管理（重要）

- 为不同用户角色分配不同的权限，只有授权的用户能够访问系统的特定功能和数据确保系统数据的安全性和完整性。
- 实现用户登录、注销功能，记录用户操作日志，便于追踪和审计。

9. 系统维护与优化（不重要）

- 提供数据备份与恢复功能，确保系统数据的安全可靠。定期备份系统数据，以防止数据丢失或系统故障。
- 支持系统升级和扩展，以适应动物园管理需求的变化。

四、报警系统分级（不一定来得及开发）

报警系统应采用分级制度，根据紧急程度逐级递增决定响应策略。例如，可以设置以下报警级别：

1. 一级报警：涉及动物生命安全或重大疾病的紧急情况，需立即处理。系统可根据预留手机号拨打电话提醒相关人员。
2. 二级报警：动物体征数据异常但未造成严重危害或饲养计划执行不到位等情况，需尽快处理。系统可发送邮件或短信提醒相关人员。
3. 三级报警：日常饲养记录缺失或数据录入错误等较小问题，可安排定期处理。

报警系统闭环管理的流程：

1.**报警触发：**报警系统根据预设的规则和条件，监测动物的健康状况、饲养记录等信息，当发现异常情况符合报警规则时，自动触发相应级别的报警。

2.**通知相关人员：**报警系统根据报警级别选择适的通知方式，通知相关责任人员，如饲养管理员、兽医等。通知方式可以包括电话呼叫、短信、邮件等。

3.**接收报警信息：**相关责任人员接收到报警信息后，需要及时查看并了解报警的具体内容和情况。系统应提供清晰明了的报警信息，包括动物种类、具体问题、位置等。

4.**处理报警：**相关责任人员根据报警信息采取相应的处理措施，针对不同级别的报警，制定相应的应对策略。一级报警需要立即处理，二级报警需要尽快处理，三级报警可以安排定期处理。

5.**解决问题：**相关责任人员在处理报警过程中，需要确保问题得到有效解决。对于一级报警和二级报警，需及时采取措施保障动物的健康和安全；对于三级报警，需要及时查明原因并采取相应措施，避免问题的再次发生。

6.**反馈和记录：**处理报警后，相关责任人员需要向系统反馈处理结果，并在系统中记录处理过程和结果。系统应提供相应的反馈和记录功能，方便责任人员进行操作。

7.**系统优化：**管理人员定期对报警系统的性能进行评估和分析，根据实际情况和反馈信息，对系统进行优化和改进。可以针对报警规则、通知方式、处理流程等方面进行调整，提高报警系统的准确性和效率。

五、饲养计划闭环系统（不一定来得及开发）

饲养计划的闭环是指在动物园信息管理系统中，通过制定、执行、监控和反馈的过程，实现对动物饲养的全面管理和持续优化。以下是饲养计划的闭环流程：

1. **计划制定：**饲养管理员根据动物的种类、年龄、健康状况等因素，制定饲养计划。计划包括每日、每周或每月的饲养任务安排，确定每种动物的饲料类型、数量和喂养时间等。
   如果动物患有疾病或健康问题，兽医可以在饲养计划中考虑到这些特殊情况，对饲养计划和管理流程进行调整和优化

2. **任务分配：**系统根据制定的饲养计划，自动将任务分配给相应的饲养员。任务分配考虑到饲养员的工作时间、技能水平和工作负荷等因素，确保任务合理分配。

3. **执行监控：**饲养员执行任务时，实时记录饲养过程中的关键信息，如喂养时间、饲料用量、动物反应等。同时，系统监控饲养过程中的异常情况，如动物健康状况异常、饲料不足等。

4. **数据采集与分析：**系统定期采集和分析动物的健康数据和饲养记录，包括体重变化、食欲情况、疾病发生率等。通过数据分析，及时发现饲养过程中存在的问题和改进空间。

5. **问题反馈与调整：**根据数据分析结果，系统生成饲养效果报告和健康预警信息。管理人员和饲养员根据报告和预警信息，及时调整饲养计划和执行策略，解决存在的问题，并优化饲养过程。

六、饲料库存自动化管理系统（不一定来得及开发）

针对动物园饲料库存管理，建立自动化管理系统同样能够提高效率、降低成本并确保饲料供应的及时性。以下是动物园饲料库存自动化管理的主要内容和流程：

1. **自动化库存登记：**建立自动化系统，对动物园所有饲料进行自动化登记和识别，包括名称、规格、数量、购买日期、供应商信息等，实现饲料信息的自动采集和录入。

2. **库存监控：**实时监测饲料库存的数量、质量和保质期等信息。如有即将过期的饲料，系统会自动发送通知提醒相关人员。通过自动化系统，管理人员可以随时查看库存情况，并及时采取补货或调拨等措施。

3. **智能化补货策略：**根据库存监控数据和需求预测模型，制定智能化的补货策略。系统可以自动分析库存变化趋势和消耗情况，智能生成补货计划，并自动向供应商下订单，实现自动化补货流程。

4. **库存记录和报告：**系统可以自动生成库存记录和报告，包括库存量、成本、动物饲养需求等数据。管理人员可以通过系统查看和分析库存数据，优化饲料库存结构和管理策略。

七、非功能需求（略）

1. 易用性：系统界面简洁明了，操作流程简单易懂，方便用户快速上手。
2. 稳定性：系统应具有高可靠性，能够长时间稳定运行，减少故障率。
3. 安全性：系统应采取必要的安全措施，保护用户数据和系统免受攻击和破坏。
4. 可扩展性：系统应具备良好的可扩展性，以便在未来添加新的功能模块或集成其他系统。

八、总结（略）

动物园信息管理系统旨在提高动物园内部人员的管理效率，保障动物健康和福利。通过实现动物数据管理、数据查询与统计、健康与福利管理等功能，可以优化动物园管理流程，提升动物生活质量。同时，系统还应满足易用性、稳定性、安全性和可扩展性等非功能需求，确保系统的稳定运行和持续发展。

